searchNodes=[{"doc":"This module minimizes the amount of work one needs to do to create a WebDriver extension. Typical usecase would look something like this:defmodule Driver8.Http do @moduledoc false use GenServer require Logger require Driver8.Session import Driver8.WireProtocol def start_link(_opts) do GenServer.start_link(__MODULE__, [], name: MyAwesomeExtension) end @impl true def init(_opts) do :ok = Driver8.Session.extend(&quot;my-awesome-extension&quot;, :get) {:ok, []} end @impl true def handle_call({:post, [&quot;my-awesome-extension&quot;, &quot;get&quot;], session_id, parameters}, _from, state) do response = ... # prepare you response here {:reply, {:ok, response}, state} end @impl true def handle_call(request, _from, state) do {:reply, GenServer.call(Driver8, request), state} end endImportant steps to create your extension are:Create a GenServerRegister it as driver level extension (Driver8.extend) or session level extension (Driver8.Session.extend)Define implementation of handle_call for your endpointsDefine catch all method and pass the message to Driver8Last step is optional (presumably you are in control of the client code that calls your extension), but it will give you a nice error message on the client end instead of killing your GenServer.","ref":"Driver8.html","title":"Driver8","type":"module"},{"doc":"In case you decide to handle routes yourself this method allows you to dispatch a call to a driver level extension. Method is expected be a Plug.Conn method (so &quot;GET&quot;, &quot;POST&quot;, etc.)","ref":"Driver8.html#call_extension/4","title":"Driver8.call_extension/4","type":"function"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Driver8.html#child_spec/1","title":"Driver8.child_spec/1","type":"function"},{"doc":"Registers the calling process as an driver level extension, responsible for handling requests on a given path. Methods can be an atom like :get or a list of atoms. Defaults to [:get, :post, :put, :delete, :head, :patch]. You can pass a different name to be used to find Driver8, defaults to Driver8.Examples:ok = Driver8.extend(&quot;my-extension&quot;) :ok = Driver8.extend(&quot;my-extension&quot;, [:get, :post]) :ok = Driver8.extend(&quot;my-extension&quot;, [:get, :post], Driver8.IKnowWhatIamDoing)After extension is registered with any of the examples call http://localhost:8085/my-extension will be translated to the message to the GenServer you have registered as extension. You are expected to have a method similar to@impl true def handle_call({:get, [&quot;my-extension&quot;], _parameters}, _from, state) do {:reply, {:ok, {200, %{&quot;result&quot; =&gt; &quot;Everything went fine.&quot;}}}, state} endor@impl true def handle_call({:get, [&quot;my-extension&quot;], _parameters}, _from, state) do {:reply, {:ok, {401, &quot;Go away!&quot;}}, state} endFirst case will result in json response, second in text response.","ref":"Driver8.html#extend/3","title":"Driver8.extend/3","type":"function"},{"doc":"Returns the status of the driver to be used in the /status endpoint.","ref":"Driver8.html#is_ready/1","title":"Driver8.is_ready/1","type":"function"},{"doc":"Starts a Driver8 process linked to the current process (to be used as a part of supervision tree).Once process is started it will register itself with default name Driver8. This name is used by Driver8.Plug to call for request handling.Options:name - value used for name registration, if not passed defaults to Driver8","ref":"Driver8.html#start_link/1","title":"Driver8.start_link/1","type":"function"},{"doc":"A Utility method that will return you a supervisor that is used to register sessions and registry where all the sessions are registered","ref":"Driver8.html#supervisor_and_registry/1","title":"Driver8.supervisor_and_registry/1","type":"function"},{"doc":"Returns current version of Driver8","ref":"Driver8.html#version/0","title":"Driver8.version/0","type":"function"},{"doc":"Plug that takes care of all endpoints related to wire protocol. All handling logic is delegated to a GenServer process registered under the name Driver8.This plug is designed primarily to be used directly (for example, passed to Plug.Adapters.Cowboy).","ref":"Driver8.Plug.html","title":"Driver8.Plug","type":"module"},{"doc":"Callback implementation for Plug.call/2.","ref":"Driver8.Plug.html#call/2","title":"Driver8.Plug.call/2","type":"function"},{"doc":"Callback implementation for Plug.init/1.","ref":"Driver8.Plug.html#init/1","title":"Driver8.Plug.init/1","type":"function"},{"doc":"An addition to Driver8.Plug that handles session routes. Typically you will not use this module directly.","ref":"Driver8.Session.Plug.html","title":"Driver8.Session.Plug","type":"module"},{"doc":"Callback implementation for Plug.call/2.","ref":"Driver8.Session.Plug.html#call/2","title":"Driver8.Session.Plug.call/2","type":"function"},{"doc":"","ref":"Driver8.Session.Plug.html#force_content_type_plug/2","title":"Driver8.Session.Plug.force_content_type_plug/2","type":"function"},{"doc":"Callback implementation for Plug.init/1.","ref":"Driver8.Session.Plug.html#init/1","title":"Driver8.Session.Plug.init/1","type":"function"},{"doc":"This module covers values and structures from the webdriver spec.","ref":"Driver8.WireProtocol.html","title":"Driver8.WireProtocol","type":"module"},{"doc":"Send error response stating that session_id client is trying to use cannot be found (was closed due to timeout, for example)","ref":"Driver8.WireProtocol.html#no_such_session/1","title":"Driver8.WireProtocol.no_such_session/1","type":"function"},{"doc":"Utility method that does exactly that: sends json response and halts current connection processing","ref":"Driver8.WireProtocol.html#send_json_and_halt/2","title":"Driver8.WireProtocol.send_json_and_halt/2","type":"function"},{"doc":"Utility method that does exactly that: sends json response and halts current connection processing","ref":"Driver8.WireProtocol.html#send_json_and_halt/3","title":"Driver8.WireProtocol.send_json_and_halt/3","type":"function"},{"doc":"Utility method that does exactly that: sends text response and halts current connection processing","ref":"Driver8.WireProtocol.html#send_text_and_halt/2","title":"Driver8.WireProtocol.send_text_and_halt/2","type":"function"},{"doc":"Utility method that does exactly that: sends text response and halts current connection processing","ref":"Driver8.WireProtocol.html#send_text_and_halt/3","title":"Driver8.WireProtocol.send_text_and_halt/3","type":"function"},{"doc":"Send error response stating that driver was not able to create a new session","ref":"Driver8.WireProtocol.html#session_not_created/1","title":"Driver8.WireProtocol.session_not_created/1","type":"function"},{"doc":"Send success response for given session_id and passing along return value (if any)","ref":"Driver8.WireProtocol.html#success/2","title":"Driver8.WireProtocol.success/2","type":"function"},{"doc":"Send error response stating that driver encountered an unexpected error (with stacktrace, if possible)","ref":"Driver8.WireProtocol.html#unhandled_error/3","title":"Driver8.WireProtocol.unhandled_error/3","type":"function"},{"doc":"Send error response stating that driver does not understand this particular command","ref":"Driver8.WireProtocol.html#unknown_command/2","title":"Driver8.WireProtocol.unknown_command/2","type":"function"},{"doc":"Driver8Best choice for writing a WebDriver remote endDriver8 provides everything you need to build a Webdriver extension. This is not a wrapper for your Selenium tests, but a basis for Remote end. Similar to what Appium does for Mobile testing, you can create your own extension and use it via standard W3C Webdriver wire protocol.","ref":"readme.html","title":"Driver8","type":"extras"},{"doc":"You can give the Driver8 a try without adding any functionality. Driver8 has two components:Driver8.Plug - Plug that takes care of capturing REST requests to your driverDriver8 - Main process (in a form of GenServer) that handles the requests passed to it by Driver8.Plug or any other process.To bootstrap Driver8 application you will need a http server. For this demo we will use Cowboy server. Run mix new demo to create a new mix application called demo. Switch to your demo folder cd demo. Change your mix.exs to look like this (project section should already look like this, you simply need to adjust application and deps sections): defmodule Demo.MixProject do use Mix.Project def project do [ app: :demo, version: &quot;0.1.0&quot;, elixir: &quot;~&gt; 1.10&quot;, start_permanent: Mix.env() == :prod, deps: deps() ] end def application do [ extra_applications: [:logger, :cowboy, :plug, :jason, :eex], mod: {Demo, []}, env: [ port: 8085 ] ] end defp deps do [ {:httpoison, &quot;~&gt; 1.6&quot;}, {:plug_cowboy, &quot;~&gt; 2.0&quot;}, {:driver8, &quot;~&gt; 0.1&quot;} ] end endNow update your main module Demo (found in lib/demo.ex) to look like this: defmodule Demo do use Application def start(_type, _args) do children = [ {Plug.Cowboy, scheme: :http, plug: Driver8.Plug, options: [port: Application.fetch_env!(:driver8, :port) |&gt; IO.inspect()]}, Driver8 ] Supervisor.start_link(children, [strategy: :one_for_one, name: Demo.Supervisor]) end endAfter that you need to get dependencies by running mix deps.get. Now you can start application by running iex -S mix. If all goes according to plan then after you open your browser and point it at http://localhost:8085/ you should see a greeting message similar to this: You are using Driver 8 (elixir) 0.1.2. Another route that should work is http://localhost:8085/status. It should return you a json with a message and ready status of the driver process.Congrats, you are running you very own webdriver extension! It can handle session creation, but that is about it. So let's make it a bit more interesting.","ref":"readme.html#getting-started","title":"Driver8 - Getting started","type":"extras"},{"doc":"Now you know how to get an webdriver application up and running. The whole point is to be able to extend webdriver protocol and to run an awesome command you want to create. For that you simply need to create a GenServer and tell the Driver8.Session which prefix you want to be registered on. Check out Driver8 module docs for session extension example.","ref":"readme.html#adding-functionality","title":"Driver8 - Adding functionality","type":"extras"}]